seaKen(x)seaRoll(x, w = 5, rule = 2)
seaKen returns a list with the following members:seaRoll returns a matrix with one row per time window containing the Sen slope, the corresponding percent, and the p-value. Rows are labelled with the final year of the window.The function seaRoll applies seaKen to rolling time windows of width w. A minimum w of five years is required. The only rules currently implemented are: (1) ignore missing data; and (2) report a result only if more than half the seasons are each missing less than half the possible comparisons between the first and last 20% of the years (Schertz et al. [1991] discuss these and related decisions about missing data).
Schertz, T.L., Alexander, R.B., and Ohe, D.J. (1991) The computer program EStimate TREND (ESTREND), a system for the detection of trends in water-quality data. Water-Resources Investigations Report 91-4040, U.S. Geological Survey.
chl27 <- sfbayChla[, 's27']
seaKen(chl27)
seaRoll(chl27)Run the code above in your browser using DataLab