## S3 method for class 'ts':
phenoAmp(x, mon.range = c(1, 12))## S3 method for class 'zoo':
phenoAmp(x, mon.range = c(1, 12))
phenoAmp gives three measures of the amplitude of a seasonal cycle: the range, the range divided by the mean, and the standard deviation divided by the mean, i.e., the coeficient of variation.These measures can be restricted to a subset of the year by giving the desired range of month numbers. This can be useful for isolating measures of, say, the spring and autumn phytoplankton blooms in temperate waters. In the case of a monthly time series, a non-missing value is required for every month or the result will be NA, so using a period shorter than one year can also help avoid any months that are typically not covered by the sampling program. Similarly, in the case of dated observations, a shorter period can help avoid times of sparse data.
The measures are annum-centric, i.e., they reflect the use of calendar year as the annum, which may not be appropriate for cases in which important features occur in winter and span two calendar years. Such cases can be handled by lagging the time series by an appropriate number of months, or by subtracting an appropriate number of days from the individual dates.
tsMake can be used to produce "ts" and "zoo" objects suitable as arguments to this function.
phenoPhase, tsMakey <- sfbayChla[, 's27']
p2 <- phenoAmp(y)
p2
apply(p2, 2, mean, na.rm=TRUE)
phenoAmp(y, c(1, 6))Run the code above in your browser using DataLab