seasonTrend(x, plot = FALSE, type = c("slope", "relative"), pval = .05, ...)mannKen).If plot = TRUE, each season for each series is represented by a bar showing the trend. The fill colour indicates whether $p < 0.05$ or not. If the fraction of missing slopes is 0.5 or more, the corresponding trends are omitted.
Parameters can be passed to the plotting function, in particular, to facet_wrap in ncol (or nrow), which determines the number of columns (or rows) of plots, and scales, which can be set to "free_y" to allow the y-axis to change for each time series. Like all
mannKen, plotSeason, facet_wrapx <- sfbayChla
seasonTrend(x)
seasonTrend(x, plot = TRUE, ncol = 4)Run the code above in your browser using DataLab