wq-package: Exploring water quality monitoring data
Description
Functions to assist in the processing and exploration of data from monitoring programs for aquatic ecosystems. The name "wq" stands for "water quality" and reflects a focus on time series data for physical and chemical properties of water, as well as the plankton. The package is intended for programs that sample approximately monthly at discrete stations, a feature of many legacy data sets. Although our emphasis is on aquatic ecosystems, most of the functions should be useful for analysis of similar-frequency time series regardless of the subject matter.Details
ll{
Package: wq
Type: Package
Version: 0.3-4
Date: 2011-09-01
Depends: R (>= 2.12.0), methods, zoo
Suggests: ggplot2, reshape
License: GPL-2
LazyLoad: yes
LazyData: yes
}